-- CRIANDO A TABELA EMPRESA
CREATE TABLE EMPRESA(
    COD_EMPRESA INT NOT NULL PRIMARY KEY,
    NOME_FANTASIA VARCHAR2(50),
    FANTASIA VARCHAR2(15)
);

-- CRIANDO SEQUENCIA PARA O CÓDIGO EMPRESA
CREATE SEQUENCE SEQ_EMP START WITH 1 INCREMENT BY 1 NOMAXVALUE;

-- CRIANDO TABELA DE UNIDADE FEDERAL
CREATE TABLE UF(
    COD_UF VARCHAR2(2) NOT NULL PRIMARY KEY,
    SIGLA_UF VARCHAR2(2) NOT NULL,
    NOME_UF VARCHAR2(30) NOT NULL
);

-- CRIANDO TABELA DE CIDADE
CREATE TABLE CIDADES(
    COD_CIDADE VARCHAR2(7) NOT NULL PRIMARY KEY,
    COD_UF VARCHAR2(2) NOT NULL,
    NOME_CIDADE VARCHAR2(50) NOT NULL,
    CONSTRAINT FK_CID1 FOREIGN KEY (COD_UF) REFERENCES UF(COD_UF)
);

-- CRIANDO TABELA DE CLIENTES
CREATE TABLE CLIENTES(
    COD_EMPRESA INT NOT NULL,
    ID_CLIENTE INT NOT NULL PRIMARY KEY,
    RAZAO_CLIENTE VARCHAR2(100) NOT NULL,
    FANTASIA VARCHAR2(15) NOT NULL,
    ENDERECO VARCHAR2(50) NOT NULL,
    NRO VARCHAR2(20) NOT NULL,
    BAIRRO VARCHAR2(20) NOT NULL,
    COD_CIDADE VARCHAR2(7) NOT NULL,
    CEP VARCHAR2(8),
    CNPJ_CPF VARCHAR2(15),
    TIPO_CLIENTE CHAR(1) CONSTRAINT CK_TC1 CHECK (TIPO_CLIENTE IN ('F', 'J')),
    DATA_CADASTRO DATE NOT NULL,
    COD_PAGTO INT,
    CONSTRAINT FK_COD_EMPR1 FOREIGN KEY (COD_EMPRESA) REFERENCES EMPRESA(COD_EMPRESA),
    CONSTRAINT FK_CLI1 FOREIGN KEY (COD_CIDADE) REFERENCES CIDADES (COD_CIDADE)
);

-- CRIANDO SEQUENCIA PARA CLIENTE
CREATE SEQUENCE SEQ_CLI START WITH 1 INCREMENT BY 1 NOMAXVALUE;

-- CRIANDO A TABELA DE FORNECEDORES
CREATE TABLE FORNECEDORES(
    COD_EMPRESA INT NOT NULL,
    ID_FOR INT NOT NULL PRIMARY KEY,
    RAZAO_FORNEC VARCHAR2(100) NOT NULL,
    FANTASIA VARCHAR2(15) NOT NULL,
    ENDERECO VARCHAR2(50) NOT NULL,
    NRO VARCHAR2(10) NOT NULL,
    BAIRRO VARCHAR2(20) NOT NULL,
    COD_CIDADE VARCHAR2(7) NOT NULL,
    CEP VARCHAR2(8),
    CNPJ_CPF VARCHAR2(15),
    TIPO_FORNEC CHAR(1) CONSTRAINT CK_TF1 CHECK (TIPO_FORNEC IN ('F','J')),
    DATA_CADASTRO DATE NOT NULL,
    COD_PAGTO INT,
    CONSTRAINT FK_COD_EMP2 FOREIGN KEY (COD_EMPRESA) REFERENCES EMPRESA (COD_EMPRESA),
    CONSTRAINT FK_FOR1 FOREIGN KEY (COD_CIDADE) REFERENCES CIDADES (COD_CIDADE)
);

-- CRIANDO SEQUENCIA PARA FORNECEDORES
CREATE SEQUENCE SEQ_FOR START WITH 1 INCREMENT BY 1 NOMAXVALUE;

-- CRIANDO TABELA DE TIPO DE MATERIAL
CREATE TABLE TIPO_MAT (
    COD_TIP_MAT INT NOT NULL PRIMARY KEY,
    DESC_TIP_MAT VARCHAR2(20) NOT NULL
);

-- CRIANDO SEQUENCIA TIPO MATERIAL
CREATE SEQUENCE SEQ_TIP_MAT START WITH 1 INCREMENT BY 1 NOMAXVALUE;

-- CRIANDO TABELA DE MATERIAL
CREATE TABLE MATERIAL (
    COD_EMPRESA INT NOT NULL,
    COD_MAT INT NOT NULL,
    DESCRICAO VARCHAR2(50) NOT NULL,
    COD_TIP_MAT INT NOT NULL,
    CONSTRAINT FK_COD_EMP3 FOREIGN KEY (COD_EMPRESA) REFERENCES EMPRESA (COD_EMPRESA),
    CONSTRAINT FK_MAT1 FOREIGN KEY (COD_TIP_MAT) REFERENCES TIPO_MAT (COD_TIP_MAT),
    CONSTRAINT PK_EMP_MAT PRIMARY KEY (COD_EMPRESA, COD_MAT)
);


-- CRIANDO TABELA DE MATERIAL DE FORNECEDORES
CREATE TABLE MAT_FORNEC (
    COD_EMPRESA INT NOT NULL,
    COD_MAT INT NOT NULL,
    ID_FOR INT NOT NULL,
    CONSTRAINT PK_MAT_FOR PRIMARY KEY (COD_EMPRESA, COD_MAT, ID_FOR),
    CONSTRAINT FK_MAT_FOR1 FOREIGN KEY (COD_EMPRESA) REFERENCES EMPRESA (COD_EMPRESA),
    CONSTRAINT FK_MAR_FOR2 FOREIGN KEY (ID_FOR) REFERENCES FORNECEDORES (ID_FOR)
);

--CRIAÇÃO DE INDEX
--CREATE INDEX IX_MAT1 ON MATERIAL (COD_EMPRESA, COD_MAT); -- Já foi indexado na criação da tabela
CREATE INDEX IX_MAT2 ON MATERIAL (COD_TIP_MAT);




